<?php
/**
* @author Guillermo Vargas guille@vargas.co.cr
* @version $Id: virtumart.plugin.php 2007/09/16 13:10:10 mic Exp $
* @package xmap
*/

defined( '_VALID_MOS' ) or die( 'Direct Access to this location is not allowed.' );

$tmp = new Xmap_virtuemart;
XmapPlugins::addPlugin( $tmp );

/** Adds support for Phpshop and Virtuemart categories to Xmap */
class Xmap_virtuemart {
	// Set to 0 if you don't want to list your products on the sitemap
	var $include_products = 1;
	
	/** Return true if this plugin handles this content */
	function isOfType( &$xmap, &$parent ) {
		if( strpos($parent->link, 'option=com_virtuemart') || strpos($parent->link, 'option=com_phpshop')) {
				return true;
		}
		return false;
	}
	
	/** Get the content tree for this kind of content */
	function &getTree( &$xmap, &$parent ) {
		$tree = null;
		$component = preg_replace('/.*option=(com_[a-z]+).*/i','$1',$parent->link);
		switch($component) {
			case 'com_phpshop':
				$tree = $this->getPhpShop($xmap, $parent);
				break;
			case 'com_virtuemart':
				$tree = $this->getVirtueMart($xmap, $parent);
				break;
		}
		return $tree;
	}

	/** Virtuemart support */
	function &getVirtueMart( &$xmap, &$parent ) {
		global $database,$mosConfig_absolute_path;

		require_once ($mosConfig_absolute_path. '/administrator/components/com_virtuemart/virtuemart.cfg.php');

		$link_query = parse_url( $parent->link );
		parse_str( html_entity_decode($link_query['query']), $link_vars);
		$catid = mosGetParam($link_vars,'category_id','');

		$query  = 
		 "SELECT a.category_id, a.category_name, a.mdate,a.category_flypage, b.category_parent_id AS pid "
		."\n FROM #__vm_category AS a, #__vm_category_xref AS b "
		."\n WHERE a.category_publish='Y' "
		."\n AND a.category_id=b.category_child_id "
		."\n ORDER BY a.list_order ASC, a.category_name ASC";

		$database->setQuery( $query );
		$rows = $database->loadObjectList();

		$list = array();
		foreach($rows as $row) {
			$node = new stdclass;
			
			$node->id = $parent->id;
			$node->browserNav = $parent->browserNav;
		    $node->name = $row->category_name;
			$node->modified = intval($row->mdate);
			$node->link = $parent->link.'&amp;page=shop.browse&amp;category_id='.$row->category_id;
			$node->pid = $row->pid;											// parent id
			$node->flypage = ($row->category_flypage ? $row->category_flypage : FLYPAGE);
			$node->tree = array();
		    $list[$row->category_id] = $node;
	    }
		
		foreach( $list as $id => $cat ) {										// move children into their parent nodes
			if( $cat->pid > 0  && !empty($list[$cat->pid]) ) {
				$list[ $cat->pid ]->tree[] = &$list[$id];
			}
		}

		if ( $this->include_products ) {
			$query  = 
		 	"SELECT a.product_id, a.product_name,a.mdate, b.category_id,c.manufacturer_id "
			."\n FROM #__vm_product AS a, #__vm_product_category_xref AS b, #__vm_product_mf_xref AS c"
			."\n WHERE a.product_publish='Y'"
			."\n AND a.product_id=b.product_id "
			."\n AND a.product_id=c.product_id "
			."\n ORDER BY a.product_name";

			$database->setQuery( $query );
			$rows = $database->loadObjectList();
			foreach ( $rows as $row ) {
				if ( empty($list[$row->category_id]) )
					continue;

				$node = new stdclass;
				$node->id = $parent->id;
				$node->browserNav = $parent->browserNav;
				$node->name = $row->product_name;
				$node->modified = intval($row->mdate);
				$node->link = 'index.php?option=com_virtuemart&amp;page=shop.product_details&amp;flypage='.$list[$row->category_id]->flypage.'&amp;category_id='.$row->category_id . '&amp;product_id=' . $row->product_id . '&amp;manufacturer_id='.$row->manufacturer_id;						// parent id
		    		$list[$row->category_id]->tree[] = $node;
	    		}
		}

		foreach( $list as $id => $cat ) {				// remove children from top tree
			if( $cat->pid > 0 ) {
				unset( $list[$id] );
			}
		}
		if ( $catid ) {
			return $list[$catid]->tree;
		}

		return $list;
	}

	/************************************************************************************************************
	 * pshop category handling taken from /administrator/components/com_phpshop/classes/ps_product_category.php *
	 * ps_product_category::get_category_tree                                                                   *
	 ************************************************************************************************************/
	/** Get an array with all 1st level Categories in PhpShop */
	function &getPhpShop( &$xmap, &$parent ) {
		global $database;

		// Show only top level categories that are published
	    $query =
		 "SELECT * FROM #__pshop_category AS a, #__pshop_category_xref AS b"
		."\n WHERE a.category_publish='Y'"
		."\n AND (b.category_parent_id='' OR b.category_parent_id='0')"
		."\n AND a.category_id=b.category_child_id"
		."\n ORDER BY a.list_order ASC, a.category_name ASC";

		$database->setQuery( $query );
		$items = $database->loadObjectList();

		$cats = array();
		foreach($items as $item) {
			$node = new stdclass;
			$node->id = $parent->id;
			$node->browserNav = $parent->browserNav;
		    $node->name = $item->category_name;
			$node->modified = intval($item->mdate);
			$node->link = $parent->link.'&amp;page=shop.browse&amp;category_id='.$item->category_id;

		    $cats[] = $node;
	    }
		return $cats;
	}
}

?>